==> foundation-2.6.1.tgz: package/NoSmoking/NoSmoking.esm.js <==
import * as React from 'react';
import { EmotionIconBase } from '@emotion-icons/emotion-icon';
export const NoSmoking = /*#__PURE__*/React.forwardRef((props, ref) => {
  const attrs = {
    "fill": "currentColor",
    "xmlns": "http://www.w3.org/2000/svg"
  };
  return /*#__PURE__*/React.createElement(EmotionIconBase, Object.assign({
    iconAttrs: attrs,
    iconVerticalAlign: "middle",
    iconViewBox: "0 0 100 100"
  }, props, {
    ref: ref
  }), /*#__PURE__*/React.createElement("g", null, /*#__PURE__*/React.createElement("path", {
    d: "M65.551 45.894l-.008.001h-.657l-.008-.001c-.63 0-1.14.51-1.14 1.14l.001 5.932v.154h.03c.077.553.533.986 1.108.986h.668v-.001l.005.001c.575 0 1.031-.433 1.109-.987h.031v-6.086c0-.63-.51-1.139-1.139-1.139zm4.24 0l-.008.001h-.656l-.008-.001c-.63 0-1.14.51-1.14 1.14h-.001l.001 6.086h.031c.077.553.533.986 1.108.986h.668v-.001l.005.001c.575 0 1.032-.433 1.109-.987h.031v-6.086a1.14 1.14 0 00-1.14-1.139z"
  }), /*#__PURE__*/React.createElement("path", {
    d: "M50 12.5c-20.712 0-37.5 16.793-37.5 37.502C12.5 70.712 29.288 87.5 50 87.5s37.5-16.788 37.5-37.498C87.5 29.293 70.712 12.5 50 12.5zm0 65.061c-15.199 0-27.56-12.362-27.56-27.559a27.435 27.435 0 016.4-17.636l13.529 13.529h-12.15l-.008-.001c-.63 0-1.14.51-1.14 1.14l.001.003h-.002v5.93c0 .63.51 1.14 1.14 1.14h20.37l17.055 17.055A27.44 27.44 0 0150 77.561zm21.161-9.926L57.633 54.106h3.463c.629 0 1.14-.51 1.14-1.14v-5.929l.001-.004c0-.63-.511-1.14-1.14-1.14l-.008.001H49.422L32.366 28.839A27.431 27.431 0 0150 22.439c15.198 0 27.56 12.367 27.56 27.562a27.43 27.43 0 01-6.399 17.634z"
  })));
});
NoSmoking.displayName = 'NoSmoking';
export const NoSmokingDimensions = {
  height: 100,
  width: 100
};

==> foundation-2.7.1.tgz: package/NoSmoking/NoSmoking.esm.js <==
import _extends from "@babel/runtime/helpers/extends";
import * as React from 'react';
import { EmotionIconBase } from '@emotion-icons/emotion-icon';
export var NoSmoking = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var attrs = {
    "fill": "currentColor",
    "xmlns": "http://www.w3.org/2000/svg"
  };
  return /*#__PURE__*/React.createElement(EmotionIconBase, _extends({
    iconAttrs: attrs,
    iconVerticalAlign: "middle",
    iconViewBox: "0 0 100 100"
  }, props, {
    ref: ref
  }), /*#__PURE__*/React.createElement("g", null, /*#__PURE__*/React.createElement("path", {
    d: "M65.551 45.894l-.008.001h-.657l-.008-.001c-.63 0-1.14.51-1.14 1.14l.001 5.932v.154h.03c.077.553.533.986 1.108.986h.668v-.001l.005.001c.575 0 1.031-.433 1.109-.987h.031v-6.086c0-.63-.51-1.139-1.139-1.139zm4.24 0l-.008.001h-.656l-.008-.001c-.63 0-1.14.51-1.14 1.14h-.001l.001 6.086h.031c.077.553.533.986 1.108.986h.668v-.001l.005.001c.575 0 1.032-.433 1.109-.987h.031v-6.086a1.14 1.14 0 00-1.14-1.139z"
  }), /*#__PURE__*/React.createElement("path", {
    d: "M50 12.5c-20.712 0-37.5 16.793-37.5 37.502C12.5 70.712 29.288 87.5 50 87.5s37.5-16.788 37.5-37.498C87.5 29.293 70.712 12.5 50 12.5zm0 65.061c-15.199 0-27.56-12.362-27.56-27.559a27.435 27.435 0 016.4-17.636l13.529 13.529h-12.15l-.008-.001c-.63 0-1.14.51-1.14 1.14l.001.003h-.002v5.93c0 .63.51 1.14 1.14 1.14h20.37l17.055 17.055A27.44 27.44 0 0150 77.561zm21.161-9.926L57.633 54.106h3.463c.629 0 1.14-.51 1.14-1.14v-5.929l.001-.004c0-.63-.511-1.14-1.14-1.14l-.008.001H49.422L32.366 28.839A27.431 27.431 0 0150 22.439c15.198 0 27.56 12.367 27.56 27.562a27.43 27.43 0 01-6.399 17.634z"
  })));
});
NoSmoking.displayName = 'NoSmoking';
export var NoSmokingDimensions = {
  height: 100,
  width: 100
};
